@@ -717,3 +717,76 @@ function sq_change_text_domain($domain_name, $directory='') {
 
 
 
+//
+// taken from 1.4.12-svn functions/global.php on 2007/12/17
+// since 1.5.2 and 1.4.12
+//
+// This code was taken from 1.4.12, because the 1.5.2 version
+// of this function has constants that are not defined in the 
+// 1.4.x series.  If you are running 1.5.x, you should be 
+// running 1.5.2+, where this function is natively included 
+// anyway.
+//
+if ((!compatibility_check_sm_version(1, 4, 12)
+ || (compatibility_check_sm_version(1, 5, 0) && !compatibility_check_sm_version(1, 5, 2)))
+ && !function_exists('sq_call_function_suppress_errors'))
+{
+function sq_call_function_suppress_errors($function, $args=NULL) {
+   $display_errors = ini_get('display_errors');
+   ini_set('display_errors', '0');
+   $ret = call_user_func_array($function, $args);
+   ini_set('display_errors', $display_errors);
+   return $ret;
+}
+}
+
+
+
+//
+// taken from functions/global.php on 2008/01/12
+// since 1.5.2
+//
+if (!function_exists('get_secured_config_value'))
+{
+function get_secured_config_value($var_name) {
+
+    static $return_values = array();
+
+    // if we can avoid it, return values that have
+    // already been retrieved (so we don't have to
+    // include the config file yet again)
+    //
+    if (isset($return_values[$var_name])) {
+        return $return_values[$var_name];
+    }
+
+
+    // load site configuration
+    //
+    require(SM_PATH . 'config/config.php');
+
+    // load local configuration overrides
+    //
+    if (file_exists(SM_PATH . 'config/config_local.php')) {
+        require(SM_PATH . 'config/config_local.php');
+    }
+
+    // if SM isn't in "secured configuration" mode,
+    // just return the desired value from the global scope
+    //
+    if (!$secured_config) {
+        global $$var_name;
+        $return_values[$var_name] = $$var_name;
+        return $$var_name;
+    }
+
+    // else we return what we got from the config file
+    //
+    $return_values[$var_name] = $$var_name;
+    return $$var_name;
+
+}
+}
+
+
+
